@@ -20,6 +20,7 @@
 #
 # Alternatively, Instant may be distributed under the terms of the BSD license.
 
+from six import string_types
 import logging, os, platform, sys
 
 # Logging wrappers
@@ -31,26 +32,30 @@ _log.setLevel(logging.INFO)
 #_log.setLevel(logging.DEBUG)
 
 # Choose method for calling external programs. use subprocess by
-# deafult, and os.system on Windows
+# default, and os.system on Windows
 _default_call_method = 'SUBPROCESS'
 if 'Windows' in platform.system() or 'CYGWIN' in platform.system():
     _default_call_method = 'OS_SYSTEM'
-_call_method = os.environ.get("INSTANT_SYSTEM_CALL_METHOD", \
+_call_method = os.environ.get("INSTANT_SYSTEM_CALL_METHOD",
                               _default_call_method)
 _log.debug('Using call method: %s'%_call_method)
 
+
 def get_log_handler():
     return _loghandler
 
+
 def get_logger():
     return _log
 
+
 def set_log_handler(handler):
     global _loghandler
     _log.removeHandler(_loghandler)
     _loghandler = handler
     _log.addHandler(_loghandler)
 
+
 def set_logging_level(level):
     import inspect
     frame = inspect.currentframe().f_back
@@ -59,8 +64,9 @@ def set_logging_level(level):
                     (inspect.getfile(frame), frame.f_lineno))
     set_log_level(level)
 
+
 def set_log_level(level):
-    if isinstance(level, str):
+    if isinstance(level, string_types):
         level = level.upper()
         assert level in ("INFO", "WARNING", "ERROR", "DEBUG")
         level = getattr(logging, level)
@@ -68,30 +74,38 @@ def set_log_level(level):
         assert isinstance(level, int)
     _log.setLevel(level)
 
+
 # Aliases for calling log consistently:
 
+
 def instant_debug(*message):
     _log.debug(*message)
 
+
 def instant_info(*message):
     _log.info(*message)
 
+
 def instant_warning(*message):
     _log.warning(*message)
 
+
 def instant_error(*message):
     _log.error(*message)
     text = message[0] % message[1:]
     raise RuntimeError(text)
 
+
 def instant_assert(condition, *message):
     if not condition:
         _log.error(*message)
         text = message[0] % message[1:]
         raise AssertionError(text)
 
+
 # Utility functions for file handling:
 
+
 def write_file(filename, text):
     "Write text to a file and close it."
     try:
@@ -101,12 +115,27 @@ def write_file(filename, text):
     except IOError as e:
         instant_error("Can't open '%s': %s" % (filename, e))
 
+
 if _call_method == 'SUBPROCESS':
-    from subprocess import Popen, PIPE, STDOUT
+
+    # NOTE: subprocess in Python 2 is not OFED-fork-safe! Check subprocess.py,
+    #       http://bugs.python.org/issue1336#msg146685
+    #       OFED-fork-safety means that parent should not
+    #       touch anything between fork() and exec(),
+    #       which is not met in subprocess module. See
+    #       https://www.open-mpi.org/faq/?category=openfabrics#ofa-fork
+    #       http://www.openfabrics.org/downloads/OFED/release_notes/OFED_3.12_rc1_release_notes#3.03
+    # However, subprocess32 backports the fix from Python 3 to 2.7.
+    if os.name == "posix" and sys.version_info[0] < 3:
+        try:
+            import subprocess32 as subprocess
+        except:
+            import subprocess
+    else:
+        import subprocess
 
     def get_status_output(cmd, input=None, cwd=None, env=None):
-        "Replacement for commands.getstatusoutput which does not work on Windows."
-        if isinstance(cmd, str):
+        if isinstance(cmd, string_types):
             cmd = cmd.strip().split()
         instant_debug("Running: " + str(cmd))
 
@@ -117,7 +146,8 @@ if _call_method == 'SUBPROCESS':
         #       which is not met in subprocess module. See
         #       https://www.open-mpi.org/faq/?category=openfabrics#ofa-fork
         #       http://www.openfabrics.org/downloads/OFED/release_notes/OFED_3.12_rc1_release_notes#3.03
-        pipe = Popen(cmd, shell=False, cwd=cwd, env=env, stdout=PIPE, stderr=STDOUT)
+        pipe = subprocess.Popen(cmd, shell=False, cwd=cwd, env=env, stdout=subprocess.PIPE,
+                     stderr=subprocess.STDOUT)
 
         (output, errout) = pipe.communicate(input=input)
         assert not errout
@@ -134,7 +164,7 @@ elif _call_method == 'OS_SYSTEM':
     def get_status_output(cmd, input=None, cwd=None, env=None):
         # We don't need function with such a generality.
         # We only need output and return code.
-        if not isinstance(cmd, str) or input is not None or \
+        if not isinstance(cmd, string_types) or input is not None or \
             cwd is not None or env is not None:
             raise NotImplementedError(
                 'This implementation (%s) of get_status_output does'
@@ -155,13 +185,6 @@ elif _call_method == 'OS_SYSTEM':
 
         output = output.decode('utf-8') if sys.version_info[0] > 2 else output
         return (status, output)
-
-elif _call_method == 'COMMANDS':
-    import commands
-    def get_status_output(*args, **kwargs):
-        status, output = commands.getstatusoutput(*args, **kwargs)
-        output = output.decode('utf-8') if sys.version_info[0] > 2 else output
-        return status, output
 else:
     instant_error('Incomprehensible environment variable'
                   ' INSTANT_SYSTEM_CALL_METHOD=%s'%_call_method)
